@@ -2,9 +2,10 @@ from __future__ import annotations
 
 import asyncio
 import datetime
-import functools
 import logging
-from asyncio import AbstractEventLoop, TimerHandle
+import math
+import time
+from asyncio import TimerHandle
 from collections.abc import Callable, Coroutine, MutableMapping
 from typing import Any, TypeVar
 
@@ -18,15 +19,6 @@ def unpack_list(value: list[T], size: int) -> list[T | None]:
     return (value + [None] * size)[:size]  # type: ignore
 
 
-def get_running_loop_or_create_one() -> AbstractEventLoop:
-    try:
-        loop = asyncio.get_event_loop()
-    except RuntimeError:
-        loop = asyncio.new_event_loop()
-        asyncio.set_event_loop(loop)
-    return loop
-
-
 def parse_datetime_to_roborock_datetime(
     start_datetime: datetime.datetime, end_datetime: datetime.datetime
 ) -> tuple[datetime.datetime, datetime.datetime]:
@@ -60,22 +52,8 @@ def parse_time_to_datetime(
     return parse_datetime_to_roborock_datetime(start_datetime, end_datetime)
 
 
-def run_sync():
-    loop = get_running_loop_or_create_one()
-
-    def decorator(func):
-        @functools.wraps(func)
-        def wrapped(*args, **kwargs):
-            return loop.run_until_complete(func(*args, **kwargs))
-
-        return wrapped
-
-    return decorator
-
-
 class RepeatableTask:
-    def __init__(self, loop: AbstractEventLoop, callback: Callable[[], Coroutine], interval: int):
-        self.loop = loop
+    def __init__(self, callback: Callable[[], Coroutine], interval: int):
         self.callback = callback
         self.interval = interval
         self._task: TimerHandle | None = None
@@ -86,7 +64,8 @@ class RepeatableTask:
             response = await self.callback()
         except RoborockException:
             pass
-        self._task = self.loop.call_later(self.interval, self._run_task_soon)
+        loop = asyncio.get_running_loop()
+        self._task = loop.call_later(self.interval, self._run_task_soon)
         return response
 
     def _run_task_soon(self):
@@ -113,10 +92,18 @@ class RoborockLoggerAdapter(logging.LoggerAdapter):
 counter_map: dict[tuple[int, int], int] = {}
 
 
-def get_next_int(min_val: int, max_val: int):
+def get_next_int(min_val: int, max_val: int) -> int:
     """Gets a random int in the range, precached to help keep it fast."""
     if (min_val, max_val) not in counter_map:
         # If we have never seen this range, or if the cache is getting low, make a bunch of preshuffled values.
         counter_map[(min_val, max_val)] = min_val
     counter_map[(min_val, max_val)] += 1
     return counter_map[(min_val, max_val)] % max_val + min_val
+
+
+def get_timestamp() -> int:
+    """Get the current timestamp in seconds since epoch.
+
+    This is separated out to allow for easier mocking in tests.
+    """
+    return math.floor(time.time())
